Package: ageutils
Type: Package
Title: Collection of Functions for Working with Age Intervals
Version: 0.1.2
Authors@R: 
    c(
      person(
        given = "Tim",
        family = "Taylor",
        role = c("aut", "cre", "cph"),
        email = "tim.taylor@hiddenelephants.co.uk", 
        comment = c(ORCID = "0000-0002-8587-7113")
      ),
      person(
        given = "Edwin",
        family = "van Leeuwen",
        role = "aut",
        email = "edwinvanl@gmail.com", 
        comment = c(ORCID = "0000-0002-2383-5305")
      )
    )
Description: Provides a collection of efficient functions for working with
  individual ages and corresponding intervals. These include functions for
  conversion from an age to an interval, aggregation of ages with associated
  counts in to intervals and the splitting of interval counts based on
  specified age distributions.
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: rlang, stats, tibble, vctrs
Suggests: dplyr, litedown, testthat (>= 3.0.0)
Depends: R (>= 3.5.0)
LazyData: true
URL: https://timtaylor.github.io/ageutils/
BugReports: https://github.com/TimTaylor/ageutils/issues
Config/testthat/edition: 3
Config/testthat/load-all: list(export_all = FALSE, helpers = TRUE)
VignetteBuilder: litedown
NeedsCompilation: no
Packaged: 2026-02-27 12:16:36 UTC; tim
Author: Tim Taylor [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-8587-7113>),
  Edwin van Leeuwen [aut] (ORCID:
    <https://orcid.org/0000-0002-2383-5305>)
Maintainer: Tim Taylor <tim.taylor@hiddenelephants.co.uk>
Repository: CRAN
Date/Publication: 2026-02-27 12:30:02 UTC
Built: R 4.6.0; ; 2026-04-28 13:45:56 UTC; unix
