# Generated by roxygen2: do not edit by hand

export(aggregate_age_counts)
export(breaks_to_interval)
export(cut_ages)
export(reaggregate_counts)
export(reaggregate_interval_counts)
export(reaggregate_interval_rates)
export(reaggregate_rates)
export(split_interval_counts)
importFrom(rlang,check_dots_empty0)
importFrom(stats,ave)
importFrom(tibble,new_tibble)
importFrom(vctrs,list_unchop)
importFrom(vctrs,new_data_frame)
importFrom(vctrs,vec_chop)
importFrom(vctrs,vec_group_loc)
